ErrorRateCounter

Struct ErrorRateCounter 

pub struct ErrorRateCounter { /* private fields */ }
Error rate counter, based on a sliding time window for error rate statistics.

Samples outside the window are evicted on the next record call, ensuring rate() is always computed from the latest samples within the window.

Implementations

Source

impl ErrorRateCounter

pub fn new(window: Duration) -> Self

pub fn record(&mut self, success: bool)

pub fn rate(&self) -> f64

pub fn total(&self) -> usize

pub fn errors(&self) -> usize