pub struct LogAlertHook;Expand description
A simple implementation that writes alerts to the standard error stream.
Does not depend on the external log crate, avoiding extra configuration in test or
minimal deployment scenarios.
Implementations
Sourceimpl LogAlertHook
impl LogAlertHook